#include "Y8950KeyboardDevice.hh"

namespace openmsx {

string_view Y8950KeyboardDevice::getClass() const
{
	return "Y8950 Keyboard Port";
}

} // namespace openmsx
